@@ -17,7 +17,7 @@ def print_debug (str):
         print str
 
 def gtk_main_quit (*args):
-    gtk.mainquit ()
+    gtk.main_quit ()
 
 class GAlternatives:
     ALTERNATIVES = 0
@@ -101,6 +101,9 @@ class GAlternatives:
         self.options_model = gtk.TreeStore (gobject.TYPE_BOOLEAN,
                                             gobject.TYPE_STRING,
                                             gobject.TYPE_STRING)
+        self.options_model.set_sort_column_id (self.PRIORITY,
+                                               gtk.SORT_DESCENDING)
+
         self.options_tv.set_model (self.options_model)
         self.set_options_columns ()
 
@@ -151,7 +154,7 @@ class GAlternatives:
             self.alternatives_selection.select_iter (iter)
         
     def mainloop (self):
-        gtk.mainloop ()
+        gtk.main ()
         
     def refresh_ui (self):
         while gtk.events_pending ():
@@ -191,6 +194,10 @@ class GAlternatives:
         self.add_opt_entry.grab_focus ()
 
     def add_option_cb (self, *args):
+        alt = self.alternative
+        unixname = alt.get_unixname ()
+        link = alt.get_link ()
+
         path = self.add_opt_entry.get_text ()
         print_debug ('I should be adding %s to the %s alternative here...' %\
                      (path, self.alternative))
@@ -211,7 +218,7 @@ class GAlternatives:
 
         priority = self.add_opt_spin.get_value ()
 
-        cmd = '/usr/sbin/update-alternatives --install %s %s %s %d > /dev/null 2>&1' % (self.alternative_link, self.alternative, path, priority)
+        cmd = '/usr/sbin/update-alternatives --install %s %s %s %d > /dev/null 2>&1' % (link, unixname, path, priority)
         result = os.system (cmd)
 
         print_debug (cmd)
@@ -224,7 +231,7 @@ class GAlternatives:
 
     def choose_opt_cb (self, *args):
         self.file_selector.show_now ()
-        gtk.mainloop ()
+        gtk.main ()
 
         filename = self.file_selector.get_filename ()
         if filename != '':
@@ -235,11 +242,18 @@ class GAlternatives:
     def close_filesel_cb (self, *args):
         self.file_selector.hide ()
         if gtk.main_level () > 1:
-            gtk.mainquit ()
+            gtk.main_quit ()
 
     def remove_option_cb (self, *args):
+        alt = self.alternative
+        selection = self.options_tv.get_selection ()
+
+        unixname = alt.get_unixname ()
+        tm, iter = selection.get_selected ()
+        option = self.options_model.get_value (iter, self.OPTIONS)
+        
         if self.ask_for_confirmation (_('Are you sure you want to remove this option?')):
-            cmd = '/usr/sbin/update-alternatives --remove %s %s > /dev/null 2>&1' % (self.alternative, self.option)
+            cmd = '/usr/sbin/update-alternatives --remove %s %s > /dev/null 2>&1' % (unixname, option)
             result = os.system (cmd)
             print_debug (cmd)
             print_debug ('Result: %d' % (result))
@@ -263,12 +277,12 @@ class GAlternatives:
 
     def set_alternative_option (self, iter):
         alt = self.alternative
-        name = alt.get_name ()
+        unixname = alt.get_unixname ()
         option = self.options_model.get_value (iter, self.OPTIONS)
 
-        result = os.system ('/usr/sbin/update-alternatives --set %s %s  > /dev/null 2>&1' % (name, option))
+        result = os.system ('/usr/sbin/update-alternatives --set %s %s  > /dev/null 2>&1' % (unixname, option))
 
-        print_debug ('/usr/sbin/update-alternatives --set %s %s > /dev/null 2>&1' % (name, option))
+        print_debug ('/usr/sbin/update-alternatives --set %s %s > /dev/null 2>&1' % (unixname, option))
         print_debug ('Result: %d' % (result))
 
         def deactivate (model, path, iter):
@@ -293,6 +307,8 @@ class GAlternatives:
         Sets up the columns for the Options list for the currently
         selected alternative.
         """
+
+        self.options_tv.set_reorderable (True)
         
         cell_renderer = gtk.CellRendererToggle ()
         cell_renderer.set_radio (True)
@@ -305,6 +321,9 @@ class GAlternatives:
         cell_renderer = gtk.CellRendererText ()
         column = gtk.TreeViewColumn (_('Priority'), cell_renderer,
                                      text=self.PRIORITY)
+        column.set_sort_order (gtk.SORT_DESCENDING)
+        column.set_sort_indicator (True)
+        column.set_sort_column_id (self.PRIORITY)
         column.set_fixed_width (50)
         self.options_tv.append_column (column)
 
@@ -351,7 +370,7 @@ class GAlternatives:
         option = self.status_menu.get_history ()
         if option == 0:
             alt.set_option_status ('auto')
-            os.system ('/usr/sbin/update-alternatives --auto %s  > /dev/null 2>&1' % (alt.get_name ()))
+            os.system ('/usr/sbin/update-alternatives --auto %s  > /dev/null 2>&1' % (alt.get_unixname ()))
         else:
             alt.set_option_status ('manual')
             tm, iter = selection.get_selected ()
@@ -459,11 +478,21 @@ class GAlternatives:
 
 if __name__ == '__main__':
     if os.getuid ():
-        sys.exit (os.system ('/usr/bin/gksu -t "%s" -m "%s" -u root %s' % 
-                             (_('Running Alternatives Configurator...'),
-                              _('<b>I need your root password to run\n'
-                                'the Alternatives Configurator.</b>'),
-                              sys.argv[0])))
+        if os.access ('/usr/bin/gksu', os.X_OK):
+            sys.exit (os.system ('/usr/bin/gksu -t "%s" -m "%s" -u root %s' % 
+                                 (_('Running Alternatives Configurator...'),
+                                  _('<b>I need your root password to run\n'
+                                    'the Alternatives Configurator.</b>'),
+                                  sys.argv[0])))
+        else:
+            dialog = gtk.MessageDialog (None, gtk.DIALOG_DESTROY_WITH_PARENT,
+                                        gtk.MESSAGE_WARNING, gtk.BUTTONS_CLOSE)
+            dialog.set_markup (_('<b>This program should be run as root and /usr/bin/gksu is not available.</b>\n\n'
+                                 'I am unable to request the password myself without gksu. Unless you have '
+                                 'modified your system to explicitely allow your normal user to modify '
+                                 'the alternatives system, GAlternatives will not work.'))
+            dialog.run ()
+            dialog.destroy ()
     
     DEBUG = False
     try:
@@ -476,4 +505,4 @@ if __name__ == '__main__':
 
     print_debug (_('Testing galternatives...'))
 
-    gtk.mainloop ()
+    gtk.main ()
