@@ -10,7 +10,8 @@ done
 
 cd translations
 
-LANGS=$(find . -name galternatives.po | cut -d '/' -f 2)
+LANGS=$(find . -name \*.po | cut -d '.' -f 2 | tr -d '/')
 for lang in ${LANGS}; do
-    msgfmt --statistics -o ${lang}/galternatives.mo ${lang}/galternatives.po
+    echo ${lang}:
+    msgfmt --statistics -o ${lang}.mo ${lang}.po
 done
